@@ -260,6 +260,12 @@ fn boxed_slice() {
 
     let boxed = vec![&1u8; 10].into_boxed_slice();
     assert_eq!(boxed.get_heap_size(), size_of::<&u8>() * boxed.len());
+
+    let rc = Rc::<[u8]>::from([1u8; 10]);
+    assert_eq!(rc.get_heap_size(), size_of::<u8>() * rc.len());
+
+    let arc = Arc::<[u8]>::from([1u8; 10]);
+    assert_eq!(arc.get_heap_size(), size_of::<u8>() * arc.len());
 }
 
 #[test]
@@ -274,6 +280,17 @@ fn boxed_str() {
     assert_eq!(arc.get_heap_size(), size_of::<u8>() * boxed.len());
 }
 
+#[test]
+fn cow() {
+    use std::borrow::Cow;
+
+    let cow: Cow<'_, str> = Cow::Borrowed("Hello world");
+    assert_eq!(cow.get_heap_size(), 0);
+
+    let cow: Cow<'_, str> = Cow::Owned("Hello world".into());
+    assert_eq!(cow.get_heap_size(), 11);
+}
+
 #[test]
 fn chrono() {
     use chrono::TimeZone;
@@ -339,14 +356,20 @@ fn once_lock_get_size() {
     );
 }
 
+#[test]
 fn compact_str() {
     const STR: &str = "Hello world";
-    const LONG_STR: &str = "A much looooonger string.";
+    const LONG_STR: &str = "A much looooonger string that exceeds 24 bytes.";
 
     let value = compact_str::CompactString::from(STR);
     assert_eq!(value.get_heap_size(), 0);
 
-    let value = compact_str::CompactString::from(LONG_STR);
+    let mut value = compact_str::CompactString::from(LONG_STR);
+    assert_eq!(value.get_heap_size(), value.capacity());
+
+    value.shrink_to_fit();
+
+    assert_eq!(value.len(), value.capacity());
     assert_eq!(value.get_heap_size(), LONG_STR.len());
 }
 
@@ -386,12 +409,43 @@ fn smallvec() {
     assert_eq!(vec.get_heap_size(), ITEM_STR.len());
     vec.push(String::new());
 
+    assert_eq!(
+        vec.get_heap_size(),
+        ITEM_STR.len() + std::mem::size_of::<String>() * vec.capacity()
+    );
+
+    vec.shrink_to_fit();
+
     assert_eq!(
         vec.get_heap_size(),
         ITEM_STR.len() + std::mem::size_of::<String>() * 3
     );
 }
 
+#[test]
+fn thin_vec() {
+    const ITEM_STR: &str = "Hello world";
+
+    assert_eq!(thin_vec::ThinVec::<String>::default().get_heap_size(), 0);
+
+    let mut vec = thin_vec::ThinVec::<String>::from([String::new(), String::from(ITEM_STR)]);
+    assert_eq!(
+        vec.get_heap_size(),
+        ITEM_STR.len()
+            + std::mem::size_of::<String>() * vec.capacity()
+            + std::mem::size_of::<usize>() * 2
+    );
+
+    vec.shrink_to_fit();
+
+    assert_eq!(
+        vec.get_heap_size(),
+        ITEM_STR.len()
+            + std::mem::size_of::<String>() * vec.len()
+            + std::mem::size_of::<usize>() * 2
+    );
+}
+
 #[test]
 fn test_enum() {
     #[derive(GetSize)]
